@@ -1,5 +1,7 @@
 package Video::PlaybackMachine::FillProducer::RandomStillFrame;
 
+our $VERSION = '0.09'; # VERSION
+
 ####
 #### Video::PlaybackMachine::FillProducer::RandomStillFrame
 ####
@@ -7,12 +9,16 @@ package Video::PlaybackMachine::FillProducer::RandomStillFrame;
 ####
 #### Plays a randomly-chosen still frame from a directory.
 ####
+#### Has, at least for now, been superseded by the SlideShow fill
+#### producer.
+####
 
 use strict;
 use warnings;
 use Carp;
 
-use base 'Video::PlaybackMachine::FillProducer';
+with 'Video::PlaybackMachine::FillProducer';
+
 use POE;
 
 use IO::Dir;
@@ -28,16 +34,8 @@ use IO::Dir;
 ##  directory => string -- Directory containing images to display
 ##  time => int -- time in seconds image should be displayed
 ##
-sub new {
-  my $type = shift;
-  my %in = @_;
 
-  my $self = $type->SUPER::new(@_);
-
-  $self->{directory} = $in{directory};
-
-  return $self;
-}
+has 'directory' => ( 'is' => 'ro', required => 1 );
 
 ############################# Object Methods ##############################
 
@@ -45,16 +43,16 @@ sub new {
 sub is_available {
   my $self = shift;
 
-  -d $self->{'directory'} or return;
-  $self->getFrames() >= 1 or return;
+  -d $self->directory() or return;
+  $self->get_frames() >= 1 or return;
   return 1;
 
 }
 
-sub getFrames {
+sub get_frames {
   my $self = shift;
 
-  my $dh = IO::Dir->new($self->{'directory'});
+  my $dh = IO::Dir->new( $self->directory() );
   my @frames = ();
   while ( my $file = $dh->read() ) {
     next if $file =~ /^\./;
@@ -74,7 +72,7 @@ sub getFrames {
 sub start {
   my $self = shift;
 
-  my @frames = $self->getFrames();
+  my @frames = $self->get_frames();
   my $frame = $frames[ rand( scalar @frames ) ];
 
   $poe_kernel->yield('still_ready', $frame, $self->get_time_layout()->min_time());
