@@ -1,5 +1,7 @@
 package Video::PlaybackMachine::TimeLayout;
 
+our $VERSION = '0.09'; # VERSION
+
 ####
 #### Interface: Video::PlaybackMachine::TimeLayout
 ####
@@ -12,18 +14,10 @@ package Video::PlaybackMachine::TimeLayout;
 ###
 ####
 
-use strict;
-use warnings;
-use Carp;
+use Moo::Role;
 
-############################# Class Constants #############################
+requires qw/min_time preferred_time/;
 
-############################## Class Methods ##############################
-
-############################# Object Methods ##############################
-
-sub min_time { }
-
-sub preferred_time { }
+no Moo::Role;
 
 1;
